/*
 * T-Plan Robot Enterprise, automated testing tool.
 * Copyright (C) 2016 T-Plan Limited (http://www.t-plan.com),
 * All rights reserved.
 */
package com.tplan.extent;

import com.tplan.robot.preferences.Preference;
import com.tplan.robot.scripting.DefaultJavaTestScript;
import com.tplan.robot.scripting.ParametrizedTestScript;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * Flush the current report (save it to the file).
 */
public class Flush extends DefaultJavaTestScript implements ParametrizedTestScript {

    @Override
    public void test() {
        // Look in the script context if there are any previously created 
        // Extent report generators and flush them
        Object o = getContext().get(ExtentReport.CONTEXT_KEY_EXTENT_REPORT_LIST);
        if (o != null && o instanceof List) {
            List<ExtentReport> reports = (List<ExtentReport>)o;
            for (ExtentReport report : reports) {
                // Flush the report
                report.flushReport();
            }
        }        
    }

    @Override
    public List<String> getParameters() {
        return null;
    }

    @Override
    public List getParameterValues(String parameterName) {
        return null;
    }

    @Override
    public void setParameters(Map<String, String> paramsAndValues) {
    }

    @Override
    public List<Preference> getVisualParameters() {
        List<Preference> l = new ArrayList<Preference>();
        String desc = "<html><body>"
                + "The Extent reports started through <a href=\"http://www.t-plan.com/robot/docs/plugins/extentreports.html#report\">Report</a> "
                + "are for performance reasons flushed (saved to file)<br/>"
                + "after the test script finishes. To flush the running report(s) at any time during<br/>"
                + "the script execution use <a href=\"http://www.t-plan.com/robot/docs/plugins/extentreports.html#flush\">Flush</a>."
                + "</body></html>";
        Preference p = new Preference("dummy", Preference.TYPE_DUMMY, "", desc);
        p.setPreferredContainerName("Flush Script Description");
        l.add(p);
        return l;
    }

    @Override
    public String getShortDescription() {
        return "Flush (save to file) the previously started Extent report.";
    }

    @Override
    public String getLongDescription() {
        return getShortDescription();
    }
}
